Package: Factoshiny
Type: Package
Title: Perform Factorial Analysis from 'FactoMineR' with a Shiny
        Application
Authors@R: c(person(given = "Pauline", family = "Vaissie", role = "aut"),
             person(given = "Astrid", family = "Monge", role = "aut"),
			 person(given = "Francois", family = "Husson", role = c("aut", "cre"), email = "francois.husson@institut-agro.fr",
             comment = c(ORCID = "0000-0002-7271-8877")))
Version: 2.7
Author: Pauline Vaissie [aut],
  Astrid Monge [aut],
  Francois Husson [aut, cre] (<https://orcid.org/0000-0002-7271-8877>)
Maintainer: Francois Husson <francois.husson@institut-agro.fr>
Depends: R (>= 4.0), FactoMineR (>= 2.3),shiny,FactoInvestigate (>=
        1.5),ggplot2
Imports:
        DT,colourpicker,grDevices,tcltk,ggrepel,shinydashboard,shinyjqui,missMDA
Description: Perform factorial analysis with a menu and draw graphs interactively thanks to 'FactoMineR' and a Shiny application.
URL: http://factominer.free.fr/graphs/factoshiny.html
License: GPL (>= 2)
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2025-01-15 16:26:22 UTC; husson
Repository: CRAN
Date/Publication: 2025-01-15 16:40:07 UTC
Built: R 4.6.0; ; 2026-05-01 03:41:11 UTC; unix
